'****************************************************************
'*  Name    : Amicus18K20.inc                                   *
'*  Author  : [Alberto Freixanet]                               *
'*  Notice  : Copyright (c) 2016 [AFreixanet]                   *
'*          : All Rights Reserved                               *
'*  Date    : 05/02/2016                                        *
'*  Version : 1.0                                               *
'*  Version : 1.1 25/03/2016                                    *
'*          :                                                   *
'****************************************************************
'
$ifndef _AMICUS18_INC
$define _AMICUS18_INC
'
' Header file for use with the Amicus18 board
'
    Device = 18F25K20

    $ifdef _ProteusDebug_
    Declare Xtal = 4
    $else
    Declare Xtal = 64    
    $endif    

    Declare Optimiser_Level = 2
    Declare Dead_Code_Remove = On

$ifndef _DisableHserial_
'-------------------------------------------------------------------------------
$if (_xtal = 64)
'Calculated Baudrate = 9598 @ Xtal 64MHz, Error = -0,02%
    Declare Hserial_RCSTA  = %10010000      ' Enable continuous receive 
    Declare Hserial_TXSTA  = %00100100      ' Enable transmit, BRGH = 1
    Declare Hserial_Clear  = On             ' Clear overflow automatically
    Declare Hserial_SPBRG  = $82            ' Baud Rate Generator Low Byte Value
    SPBRGH         = $06                    ' Baud Rate Generator High Byte Value
    BAUDCON.3      = 1                      ' Enable the 16 bit Baud Rate Generator
'
$elseif (_xtal = 4)
' Declare 9600 Bauds
    Declare Hserial_Baud = 9600         ' Set baud rate to 9600, just For statistic
    Declare Hserial_RCSTA = %10010000   ' Enable serial port and continuous receive
    Declare Hserial_TXSTA = %00100000   ' Enable transmit and asynchronous mode
    Declare Hserial_Clear = On          ' Enable Error clearing on received characters
    Declare Hserial_SPBRG  = 25         ' Baud Rate Generator Low Byte Value
    SPBRGH  = 0                         ' Baud Rate Generator High Byte Value
    BAUDCON.3 = 1                       ' Enable the 16 bit Baud Rate Generator
'
$elseif (_xtal = 40)
    Declare Hserial_Baud = 9600         ' Set baud rate to 9600
    Declare Hserial_RCSTA = %10010000   ' Enable serial port and continuous receive
    Declare Hserial_TXSTA = %00100000   ' Enable transmit and asynchronous mode
    Declare Hserial_Clear = On          ' Enable Error clearing on received characters
'
$else
    Declare Hserial_Baud = 9600         ' Set baud rate to 9600
    Declare Hserial_RCSTA = %10010000   ' Enable serial port and continuous receive
    Declare Hserial_TXSTA = %00100100   ' Enable transmit and asynchronous mode
    Declare Hserial_Clear = On          ' Enable Error clearing on received characters
$endif
'-------------------------------------------------------------------------------
$endif

$if (_xtal = 64)
Config_Start
    Debug = OFF      ' Background debugger disabled' RB6 and RB7 configured as general purpose I/O pins
    XINST = OFF      ' Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
    STVREN = OFF     ' Reset on stack overflow/underflow disabled
    $ifdef WatchDog_On
    WDTEN = On       ' WDT always enabled
    $else
    WDTEN = Off      ' WDT not enabled (control is placed on SWDTEN bit)
    $endif
    FCMEN = OFF      ' Fail-Safe Clock Monitor disabled
    FOSC = HSPLL     ' HS oscillator, PLL enabled and under software control
    IESO = OFF       ' Two-Speed Start-up disabled
    WDTPS = 64       ' 1:64
    BOREN = OFF      ' Brown-out Reset disabled in hardware and software
    BORV = 18        ' VBOR set to 1.8 V nominal
    MCLRE = On       ' MCLR pin enabled, RE3 input pin disabled
    HFOFST = OFF     ' The system clock is held off until the HF-INTOSC is stable.
    LPT1OSC = OFF    ' T1 operates in standard power mode
    PBADEN = OFF     ' PORTB<4:0> pins are configured as digital I/O on Reset
    CCP2MX = PORTC   ' CCP2 input/output is multiplexed with RC1
    LVP = OFF        ' Single-Supply ICSP disabled
    Cp0 = OFF        ' Block 0 (000800-001FFFh) not code-protected
    CP1 = OFF        ' Block 1 (002000-003FFFh) not code-protected
    CPB = OFF        ' Boot block (000000-0007FFh) not code-protected
    CPD = OFF        ' Data EEPROM not code-protected
    WRT0 = OFF       ' Block 0 (000800-001FFFh) not write-protected
    WRT1 = OFF       ' Block 1 (002000-003FFFh) not write-protected
    WRTB = OFF       ' Boot block (000000-0007FFh) not write-protected
    WRTC = OFF       ' Configuration registers (300000-3000FFh) not write-protected
    WRTD = OFF       ' Data EEPROM not write-protected
    EBTR0 = OFF      ' Block 0 (000800-001FFFh) not protected from table reads executed in other blocks
    EBTR1 = OFF      ' Block 1 (002000-003FFFh) not protected from table reads executed in other blocks
    EBTRB = OFF      ' Boot block (000000-0007FFh) not protected from table reads executed in other blocks
Config_End
'
$else
'
Config_Start
    Debug = OFF      ' Background debugger disabled' RB6 and RB7 configured as general purpose I/O pins
    XINST = OFF      ' Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
    STVREN = OFF     ' Reset on stack overflow/underflow disabled
    $ifdef WatchDog_On
    WDTEN = On       ' WDT always enabled
    $else
    WDTEN = Off      ' WDT not enabled (control is placed on SWDTEN bit)
    $endif
    FCMEN = OFF      ' Fail-Safe Clock Monitor disabled
    FOSC = HS        ' HS oscillator, PLL disabled.
    IESO = OFF       ' Two-Speed Start-up disabled
    WDTPS = 64       ' 1:64
    BOREN = OFF      ' Brown-out Reset disabled in hardware and software
    BORV = 18        ' VBOR set to 1.8 V nominal
    MCLRE = On       ' MCLR pin enabled, RE3 input pin disabled
    HFOFST = OFF     ' The system clock is held off until the HF-INTOSC is stable.
    LPT1OSC = OFF    ' T1 operates in standard power mode
    PBADEN = OFF     ' PORTB<4:0> pins are configured as digital I/O on Reset
    CCP2MX = PORTC   ' CCP2 input/output is multiplexed with RC1
    LVP = OFF        ' Single-Supply ICSP disabled
    Cp0 = OFF        ' Block 0 (000800-001FFFh) not code-protected
    CP1 = OFF        ' Block 1 (002000-003FFFh) not code-protected
    CPB = OFF        ' Boot block (000000-0007FFh) not code-protected
    CPD = OFF        ' Data EEPROM not code-protected
    WRT0 = OFF       ' Block 0 (000800-001FFFh) not write-protected
    WRT1 = OFF       ' Block 1 (002000-003FFFh) not write-protected
    WRTB = OFF       ' Boot block (000000-0007FFh) not write-protected
    WRTC = OFF       ' Configuration registers (300000-3000FFh) not write-protected
    WRTD = OFF       ' Data EEPROM not write-protected
    EBTR0 = OFF      ' Block 0 (000800-001FFFh) not protected from table reads executed in other blocks
    EBTR1 = OFF      ' Block 1 (002000-003FFFh) not protected from table reads executed in other blocks
    EBTRB = OFF      ' Boot block (000000-0007FFh) not protected from table reads executed in other blocks
Config_End
$endif

    Symbol CR = 13      ' carriage return
    Symbol LF = 10      ' Linefeed
    Symbol BS = 08      ' Backspace
    Symbol ESC = $1B    ' Escape
    Symbol TRUE = 1
    Symbol FALSE = 0
    Symbol ACK = 6
    Symbol STX = 2
    Symbol ETX = 3
    Symbol _SPACE = $20

    ' Declare all pins digital
    ANSEL = 0
    ANSELH = 0
    ADCON0 = 0
    CM1CON0 = 0
    CM2CON0 = 0
'-------------------------------------------------------------------------------
$endif      ' _AMICUS18_INC

